#ifndef NT2_INCLUDE_FUNCTIONS_MAXIMUM_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_MAXIMUM_HPP_INCLUDED

#include <nt2/reduction/include/functions/maximum.hpp>

#endif
